@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu-tab.h,v 1.24 2011/01/09 01:58:24 bowkenken Exp $
+* $Id: amenu-tab.h,v 1.26 2014/01/16 18:07:19 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_TAB_H
@@ -34,6 +34,10 @@
 /* ưޡ˥塼 */
 
 static menu_t	ls_menu_auto_mark
+		[1 + AUTO_MARK_MAX_N
+		+ (3 * AUTO_MARK_PAGE_N) + 2];
+
+static menu_t	ls_menu_auto_mark_sel_edit
 		[1 + (14 * AUTO_MARK_MAX_N)
 		+ (3 * AUTO_MARK_PAGE_N) + 2];
 
