@@ -216,6 +216,10 @@ long	add_mp( chr_t *chr, long n, bool_t flg_vfx );
 rate_t	add_resi( chr_t *chr, resi_kind_t kind, rate_t n, bool_t flg_vfx );
 gold_t	get_chr_gold( chr_t *chr );
 gold_t	add_chr_gold( chr_t *chr, gold_t gold );
+rate_t	use_contribution_rate( chr_t *chr );
+bool_t	use_contribution( chr_t *chr, rate_t rate );
+bool_t	chk_pay_contribution( chr_t *chr, gold_t gold );
+bool_t	pay_contribution( chr_t *chr, gold_t gold );
 void	curs_attrset_chr( chr_t *chr, long n, bool_t flg_crtcl );
 square_t	*get_square( chr_t *chr );
 void	set_square( chr_t *chr, square_t *sq );
@@ -227,6 +231,10 @@ bool_t	cmp_chr( chr_t *p1, chr_t *p2 );
 rate_t	calc_rate_equip(
 	chr_t *chr, abl_kind_t abl_main, abl_kind_t abl_sub
 );
+rate_t	calc_rate_equip_flg_msg(
+	chr_t *chr, abl_kind_t abl_main, abl_kind_t abl_sub,
+	bool_t flg_msg
+);
 bool_t	chk_find_chr( chr_t *p1, chr_t *p2 );
 void	clr_all_chr_flg_blast( void );
 bool_t	is_mbr( chr_t *p );
