@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.h,v 1.42 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: curs.h,v 1.47 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CURS_H
@@ -71,18 +71,51 @@
 * °
 ***************************************************************/
 
+/* ӽѤ g_curs_attr ⽤뤳 */
+
 typedef enum {
 	CURS_ATTR_N_NORMAL,
 	CURS_ATTR_N_REV,
 	CURS_ATTR_N_ERR,
+
 	CURS_ATTR_N_MENU_NORMAL,
 	CURS_ATTR_N_MENU_DIS,
 	CURS_ATTR_N_MENU_SEL,
-	CURS_ATTR_N_MAP_ITEM,
+
+	CURS_ATTR_N_MAP_CRSR,
 	CURS_ATTR_N_MAP_SQUARE,
+	CURS_ATTR_N_MAP_WALL,
+	CURS_ATTR_N_MAP_FLOOR,
+	CURS_ATTR_N_MAP_DOOR,
+	CURS_ATTR_N_MAP_STAIRS,
+	CURS_ATTR_N_MAP_TRAP,
 	CURS_ATTR_N_MAP_MNSTR,
 	CURS_ATTR_N_MAP_NPC,
-	CURS_ATTR_N_MAP_CRSR,
+	CURS_ATTR_N_MAP_PET,
+
+	CURS_ATTR_N_MAP_ITEM,
+	CURS_ATTR_N_MAP_ITEM_WPN,
+	CURS_ATTR_N_MAP_ITEM_ARMOR,
+	CURS_ATTR_N_MAP_ITEM_POTION,
+	CURS_ATTR_N_MAP_ITEM_SCROLL,
+	CURS_ATTR_N_MAP_ITEM_STICK,
+	CURS_ATTR_N_MAP_ITEM_ACCE,
+	CURS_ATTR_N_MAP_ITEM_INST,
+	CURS_ATTR_N_MAP_ITEM_LIGHT,
+	CURS_ATTR_N_MAP_ITEM_SPIKE,
+	CURS_ATTR_N_MAP_ITEM_FOOD,
+	CURS_ATTR_N_MAP_ITEM_CHEST,
+	CURS_ATTR_N_MAP_ITEM_RARE_GOODS,
+	CURS_ATTR_N_MAP_ITEM_BONE,
+	CURS_ATTR_N_MAP_ITEM_COIN,
+	CURS_ATTR_N_MAP_ITEM_JUNK,
+
+	CURS_ATTR_N_MBR_1,
+	CURS_ATTR_N_MBR_2,
+	CURS_ATTR_N_MBR_3,
+	CURS_ATTR_N_MBR_4,
+	CURS_ATTR_N_MBR_5,
+	CURS_ATTR_N_MBR_6,
 
 	CURS_ATTR_N_FX_MBR_PLUS,
 	CURS_ATTR_N_FX_MBR_MINUS,
@@ -92,19 +125,12 @@ typedef enum {
 	CURS_ATTR_N_FX_MNSTR_CRTCL,
 	CURS_ATTR_N_VFX,
 
-	CURS_ATTR_N_MBR_1,
-	CURS_ATTR_N_MBR_2,
-	CURS_ATTR_N_MBR_3,
-	CURS_ATTR_N_MBR_4,
-	CURS_ATTR_N_MBR_5,
-	CURS_ATTR_N_MBR_6,
-
 	CURS_ATTR_N_HEAT,
 	CURS_ATTR_N_COLD,
 	CURS_ATTR_N_MIND,
 	CURS_ATTR_N_ACID,
 
-	CURS_ATTR_MAX_N,
+	CURS_ATTR_N_MAX_N,
 
 	CURS_ATTR_N_MAP_NORMAL = CURS_ATTR_N_NORMAL,
 } curs_attr_n_t;
