@@ -5,14 +5,17 @@ extern "C" {
 #endif
 
 void	init_dun( void );
+void	init_crsr_ptn( void );
 void	reset_static_dun( void );
 long	get_crsr_ptn_max_n( void );
 long	set_crsr_ptn_max_n( long n );
-long	get_crsr_ptn_n( void );
-long	set_crsr_ptn_n( long n );
+long	get_main_crsr_ptn_n( void );
+long	set_main_crsr_ptn_n( long n );
+long	get_sub_crsr_ptn_n( void );
+long	set_sub_crsr_ptn_n( long n );
 void	reset_crsr_ptn( void );
 void	reset_dun( bool_t flg_wall );
-crsr_ptn_t	*get_crsr_ptn( void );
+crsr_ptn_t	*get_main_crsr_ptn( void );
 crsr_ptn_t	*get_sub_crsr_ptn( void );
 bool_t	set_crsr_ptn( crsr_ptn_t *dst, crsr_ptn_t *src );
 void	up_dun_town( void );
@@ -80,6 +83,9 @@ void	set_map_total_crsr_ptn(
 	pos_t *crsr, crsr_ptn_t *ptn,
 	long x, long y, long dx, long dy
 );
+curs_attr_n_t	get_curs_attr_n_map_obj(
+	char mjr, char mnr, flg_map_t flg
+);
 void	line_path( long x1, long y1, long x2, long y2, sect_t sect );
 void	put_path( long x, long y, long dx, long dy, sect_t sect );
 bool_t	open_door( long n );
