@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.h,v 1.37 2011/01/09 01:58:25 bowkenken Exp $
+* $Id: fight.h,v 1.39 2014/03/02 00:40:47 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	FIGHT_H
@@ -79,6 +79,12 @@ typedef enum {
 	ATTACK_KIND_MAX_N,
 } attack_kind_t;
 
+/* MONǽȤե饰 */
+#define	FLG_ATTACK_MONK	TRUE
+
+/* HUNǽȤե饰 */
+#define	FLG_ATTACK_THROW	TRUE
+
 /* ǡ */
 
 typedef struct {
