@@ -61,6 +61,7 @@ void	set_modifier_all_song_sub(
 	chr_t *chr,
 	spell_tab_t *tab, extent_kind_t extent
 );
+void	set_modifier_all_song_limit( chr_t *chr, spell_tab_t *tab );
 void	set_modifier_song( modifier_t *mod, spell_tab_t *tab );
 void	quaff_potion( chr_t *chr, item_t *item, bool_t flg_dec );
 bool_t	quaff_potion_std( chr_t *chr, fx_kind_t fx_k );
@@ -213,6 +214,14 @@ bool_t	pow_up_wpn_dam( item_t *wpn );
 bool_t	pow_up_armor_def( item_t *armor );
 bool_t	pow_up_armor_crtcl( item_t *armor );
 bool_t	pow_up_armor_ac( item_t *armor );
+long	calc_per_pow_up_wpn_hit( item_t *wpn );
+long	calc_per_pow_up_wpn_crtcl( item_t *wpn );
+long	calc_per_pow_up_wpn_dam( item_t *wpn );
+long	calc_per_pow_up_wpn( item_t *wpn );
+long	calc_per_pow_up_armor_def( item_t *armor );
+long	calc_per_pow_up_armor_crtcl( item_t *armor );
+long	calc_per_pow_up_armor_ac( item_t *armor );
+long	calc_per_pow_up_armor( item_t *armor );
 bool_t	protect_armor( item_t *armor );
 void	fx_cast_spell( chr_t *chr, spell_tab_t *tab );
 void	fx_word_of_destruction( chr_t *chr, spell_tab_t *tab );
