@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.c,v 1.216 2011/01/09 01:58:25 bowkenken Exp $
+* $Id: gfile.c,v 1.218 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -3145,11 +3145,11 @@ stay_inn_kind_t	trans_idx_to_stay_inn_kind( long idx )
 
 /***************************************************************
 * ɲμफ饤ǥåѴ
-* request_kind_t k : ɲμ
+* stay_inn_kind_t k : ɲμ
 * return : ǥå
 ***************************************************************/
 
-long	trans_stay_inn_kind_to_idx( request_kind_t k )
+long	trans_stay_inn_kind_to_idx( stay_inn_kind_t k )
 {
 	long	max_idx;
 	long	i;
