@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.h,v 1.26 2011/01/09 01:58:25 bowkenken Exp $
+* $Id: gfile.h,v 1.29 2014/03/15 01:49:20 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_H
@@ -83,10 +83,15 @@
 #define	STR_EXT_NAME_BUG_REPO_CNF	".txt"
 #define	STR_EXT_NAME_BUG_REPO_REP	".txt"
 
+#if	defined( D_DOS ) || defined( D_MFC )
+# define	STR_DIR_NAME_GAME	"_lnl"
+#else
+# define	STR_DIR_NAME_GAME	".lnl"
+#endif
+
 #define	STR_ENV_HOME	"HOME"
 #define	STR_SLASH	"/"
 #define	STR_DIR_NAME_CUR	"."
-#define	STR_DIR_NAME_GAME	".lnl"
 #define	STR_FILE_NAME_TMP	"tmp"
 
 #define	STR_DIR_NAME_USR	"usr"
