@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.73 2010/02/23 16:47:57 bowkenken Exp $
+* $Id: gmain.h,v 1.79 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
@@ -37,6 +37,8 @@
 
 #if	defined( D_GTK )
 /**/
+#elif	defined( D_IPHONE )
+# include	"config-iphone.h"
 #elif	defined( D_WS )
 # include	"config-win.h"
 #elif	defined( D_MFC )
@@ -101,6 +103,10 @@
 # include	<unistd.h>
 #endif	/* HAVE_UNISTD_H */
 
+#ifdef	HAVE_GPM_H
+# include	<gpm.h>
+#endif	/* HAVE_GPM_H */
+
 #ifndef	EXIT_SUCCESS
 # define	EXIT_SUCCESS	0
 #endif	/* EXIT_SUCCESS */
@@ -111,6 +117,15 @@
 
 /***************************************************************/
 
+#if	defined( D_WS ) \
+	|| defined( D_GTK ) \
+	|| defined( D_IPHONE ) \
+	|| defined( D_MFC )
+# define	D_ALL_GUI	1
+#endif
+
+/***************************************************************/
+
 #include	"misc.h"
 #include	"turn.h"
 #include	"msg-t.h"
@@ -165,6 +180,12 @@ EXTERN bool_t	g_flg_cui;
 /* GUI ⡼ */
 EXTERN bool_t	g_flg_gui;
 
+/* CUI ޥ⡼ */
+EXTERN bool_t	g_flg_cui_mouse;
+
+/* CUI ޥ⡼ɻ˱Υܥؤ뤫? */
+EXTERN bool_t	g_flg_cui_mouse_swap_btn;
+
 /* ΥХåե򥪥ץǻꤵ줿? */
 EXTERN long	g_audio_buf_siz_arg_overwrite;
 
