@@ -137,8 +137,8 @@ menu_t	*get_ls_menu_sel_obj( void );
 menu_t	*get_menu_dflt_main( void );
 void	set_menu_dflt_main( menu_t *p );
 void	update_crsr( void );
-pos_t	*get_crsr( void );
-pos_t	*get_pre_crsr( void );
+pos_t	*get_main_crsr( void );
+pos_t	*get_pre_main_crsr( void );
 pos_t	*get_sub_crsr( void );
 pos_t	*get_pre_sub_crsr( void );
 long	get_sel_mbr_n( void );
