@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: msg.c,v 1.51 2010/01/12 05:08:18 bowkenken Exp $
+* $Id: msg.c,v 1.54 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -80,9 +80,10 @@
 #elif	defined( D_DOS )
 # define	STR_DFLT_LANG	"ja_JP.SJIS"
 #elif	defined( D_GTK )
-# define	STR_DFLT_LANG	"ja_JP.UTF-8"
+# define	STR_DFLT_LANG	"ja_JP.utf8"
 #else
-# define	STR_DFLT_LANG	"ja_JP.eucJP"
+# define	STR_DFLT_LANG	"ja_JP.utf8"
+/*# define	STR_DFLT_LANG	"ja_JP.eucJP"*/
 #endif
 
 /* μ */
@@ -121,6 +122,11 @@ static lang_t	lang_tab[LANG_TAB_MAX_N] = {
 		STR_LANG_NAME_JAPANESE_UTF_8,
 		LANG_KIND_JAPANESE_UTF_8,
 	},
+	{
+		"ja_JP.utf8",
+		STR_LANG_NAME_JAPANESE_UTF_8,
+		LANG_KIND_JAPANESE_UTF_8,
+	},
 	{
 		"ja_JP.SJIS",
 		STR_LANG_NAME_JAPANESE_SJIS,
@@ -259,7 +265,7 @@ void	init_msg( void )
 			lang = STR_DFLT_LANG;
 #ifdef	D_GTK
 		if( strcmp( lang, "ja_JP.eucJP" ) == 0 )
-			lang = "ja_JP.UTF-8";
+			lang = "ja_JP.utf8";
 #endif
 	} else {
 		lang = g_language;
