@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2011 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2014 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.255 2011/01/09 01:58:25 bowkenken Exp $
+* $Id: party.c,v 1.258 2014/01/07 23:40:42 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -241,7 +241,6 @@ void	reset_static_party( void )
 void	init_party_dflt( void )
 {
 	race_t	race;
-	item_t	*item;
 	item_kind_dat_t	sub_kind;
 	long	i;
 
@@ -456,7 +455,7 @@ void	init_party_dflt( void )
 
 	i = 1;
 	sub_kind.potion = POTION_KIND_RUM;
-	item = init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
+	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			TRUE, FALSE, FALSE );
 
 	/* stick */
@@ -761,14 +760,40 @@ void	init_party_debug( void )
 			FALSE, FALSE, FALSE );
 
 	i = 1;
-	sub_kind.scroll = SCROLL_KIND_RECALL;
-	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
-			FALSE, FALSE, FALSE );
+	sub_kind.scroll = SCROLL_KIND_POW_UP_WPN_HIT;
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			TRUE, FALSE, FALSE );
+	inc_item( item, +98 );
 
 	i = 1;
-	sub_kind.scroll = SCROLL_KIND_SLEEP;
-	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+	sub_kind.scroll = SCROLL_KIND_POW_UP_WPN_CRTCL;
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
 			TRUE, FALSE, FALSE );
+	inc_item( item, +98 );
+
+	i = 1;
+	sub_kind.scroll = SCROLL_KIND_POW_UP_WPN_DAM;
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			TRUE, FALSE, FALSE );
+	inc_item( item, +98 );
+
+	i = 1;
+	sub_kind.scroll = SCROLL_KIND_POW_UP_ARMOR_DEF;
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			TRUE, FALSE, FALSE );
+	inc_item( item, +98 );
+
+	i = 1;
+	sub_kind.scroll = SCROLL_KIND_POW_UP_ARMOR_CRTCL;
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			TRUE, FALSE, FALSE );
+	inc_item( item, +98 );
+
+	i = 1;
+	sub_kind.scroll = SCROLL_KIND_POW_UP_ARMOR_AC;
+	item = init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			TRUE, FALSE, FALSE );
+	inc_item( item, +98 );
 
 	i = 2;
 	sub_kind.scroll = SCROLL_KIND_IDENTIFY_ITEM;
@@ -800,6 +825,16 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
 			TRUE, FALSE, FALSE );
 
+	i = 5;
+	sub_kind.scroll = SCROLL_KIND_RECALL;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			FALSE, FALSE, FALSE );
+
+	i = 5;
+	sub_kind.scroll = SCROLL_KIND_SLEEP;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_SCROLL, &sub_kind,
+			TRUE, FALSE, FALSE );
+
 	/* potion */
 
 	i = 1;
@@ -823,17 +858,17 @@ void	init_party_debug( void )
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			TRUE, FALSE, FALSE );
 
-	i = 1;
-	sub_kind.potion = POTION_KIND_FLY;
-	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
-			TRUE, FALSE, FALSE );
-
 	i = 1;
 	sub_kind.potion = POTION_KIND_RUM;
 	item = init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
 			TRUE, FALSE, FALSE );
 	inc_item( item, +16 );
 
+	i = 2;
+	sub_kind.potion = POTION_KIND_FLY;
+	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
+			TRUE, FALSE, FALSE );
+
 	i = 3;
 	sub_kind.potion = POTION_KIND_RESI_PHYS;
 	init_mbr_item( ls_mbr[i], ITEM_KIND_POTION, &sub_kind,
@@ -2912,11 +2947,8 @@ mbr_t	*get_mbr_nearest( long x, long y )
 	mbr_t	*p, *ret_p;
 	long	min_r, tmp_r;
 	long	n;
-	dun_t	*dun;
 	long	i;
 
-	dun = get_dun();
-
 	min_r = MAP_MAX_X + MAP_MAX_Y;
 	n = 0;
 	ret_p = NULL;
@@ -2964,11 +2996,8 @@ mbr_t	*get_mbr_near( long x, long y )
 	mbr_t	*p, *ret_p;
 	long	min_r, tmp_r;
 	long	n;
-	dun_t	*dun;
 	long	i;
 
-	dun = get_dun();
-
 	min_r = MAP_MAX_X + MAP_MAX_Y;
 	n = 0;
 	ret_p = NULL;
@@ -3017,7 +3046,6 @@ mbr_t	*get_mbr_disperse( mbr_t *mbr )
 	long	min_r, tmp_r;
 	long	n;
 	long	x, y;
-	dun_t	*dun;
 	long	i;
 
 	if( mbr == NULL )
@@ -3026,8 +3054,6 @@ mbr_t	*get_mbr_disperse( mbr_t *mbr )
 	x = mbr->x;
 	y = mbr->y;
 
-	dun = get_dun();
-
 	min_r = MAP_MAX_X + MAP_MAX_Y;
 	n = 0;
 	ret_p = NULL;
@@ -3078,11 +3104,8 @@ mbr_t	*get_mbr_randm( long x, long y )
 {
 	mbr_t	*p, *ret_p;
 	long	n;
-	dun_t	*dun;
 	long	i;
 
-	dun = get_dun();
-
 	n = 0;
 	ret_p = NULL;
 
@@ -3121,7 +3144,6 @@ mbr_t	*get_mbr_stagger( mbr_t *mbr )
 	long	min_r, tmp_r;
 	long	n;
 	long	x, y;
-	dun_t	*dun;
 	long	i;
 
 	if( mbr == NULL )
@@ -3134,8 +3156,6 @@ mbr_t	*get_mbr_stagger( mbr_t *mbr )
 	x = mbr->x;
 	y = mbr->y;
 
-	dun = get_dun();
-
 	min_r = MAP_MAX_X + MAP_MAX_Y;
 	n = 0;
 	ret_p = NULL;
@@ -3219,11 +3239,8 @@ mbr_t	*get_mbr_hp_mp_min_max( bool_t flg_hp, long min_max )
 	rate_t	min_max_rate, tmp_rate;
 	long	min_max_n, tmp_n;
 	long	n;
-	dun_t	*dun;
 	long	i;
 
-	dun = get_dun();
-
 	if( min_max >= +1 ){
 		min_max_rate = (rate_t)0;
 		min_max_n = 0;
